@@ -51,6 +51,7 @@ package com.openexchange.publish.microformats;
 
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -72,6 +73,7 @@ import com.openexchange.groupware.infostore.InfostoreExceptionCodes;
 import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.html.HtmlService;
 import com.openexchange.java.Strings;
 import com.openexchange.log.LogFactory;
 import com.openexchange.publish.Publication;
@@ -140,7 +142,10 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
             final Publication publication = infostorePublisher.getPublication(ctx, args.get(SITE));
             if (publication == null || !publication.isEnabled()) {
                 resp.setStatus(HttpServletResponse.SC_NOT_FOUND);
-                resp.getWriter().println("Don't know site " + args.get(SITE));
+                final PrintWriter writer = resp.getWriter();
+                final HtmlService htmlService = MicroformatServlet.htmlService;
+                writer.println("Unknown site " + (null == htmlService ? "" : htmlService.encodeForHTML(args.get(SITE))));
+                writer.flush();
                 return;
             }
             if (!checkProtected(publication, args, resp)) {
